==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/digest_shortcut_hosyu.php <==
<?php
//==============================================================
// Program Name		: 
// File Name		: digest_shortcut_hosyu.php
//--------------------------------------------------------------
// Date             : 2000/10/10
// Author           : M Iura
//--------------------------------------------------------------
// Note				: ֥åޡɽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 2002/01/15 Update
//                  : 
//==============================================================

require("jetjob.inc");
require("common_check.inc");	// 
require("common_login.php");	// 

define("DELETE",		$JJ_IMG_ROOT . "body/delete.gif");
define("IMG_SPACER",	$JJ_IMG_ROOT . "spacer.gif");		// 򥤥᡼


//==============================================================
// Function Name    : Get_bkmk
//--------------------------------------------------------------
// Note		        : ֥åޡ
//                  :
//==============================================================
Function Get_bkmk()
{
	global $JJ_USERNAME;

	$title=$url=$comment=$no=array();
	$db = new DB_Test;
	$db->query("SELECT * FROM bkmk_digest WHERE login_id = '$JJ_USERNAME' ORDER BY linkid, subcategoryid");
	$cnt = $db->nf();
	$x = 0;
	while ($db->next_record()) {
		$no[$x]     = $db->f("bkmk_digest_id");
		$linkid[$x] = $db->f("linkid");
		$subcat[$x] = $db->f("subcategoryid");
		$x++;
	}

	for ($x=0; $x<$cnt; $x++) {
		$db->query("SELECT * FROM bkmk_link WHERE subcategoryid = '$subcat[$x]' AND linkid = '$linkid[$x]'");
		$db->next_record();
		$title[$x] = $db->f("link_title");
		$url[$x] = $db->f("url");
		$comment[$x] = $db->f("biko");
	}

	$db->close();
	return array($title, $url, $comment, $no) ;
}


//==============================================================
// Function Name    : Print_bkmk
//--------------------------------------------------------------
// Note		        : Ǽľ
//                  :
//==============================================================
Function Print_bkmk($MODE)
{
	global $JJ_USERNAME;

	// ǡ
	list ($title, $url, $comment, $no) = Get_bkmk();

	print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"600\">\n");
	print("<tr align=\"center\">\n");
	print("<td width=\"50%\" class=\"color00\"><font color=\"white\"><b>硼ȥ󥯰</b></font></td>\n");
	print("<td width=\"50%\" bgcolor=\"#cccccc\">&nbsp;</td>\n");
	print("</tr>\n");
	print("<tr class=\"color00\">\n");
	printf("<td colspan=\"2\"><img src=\"%s\" width=\"1\" height=\"1\" alt=\"\"></td>\n", IMG_SPACER);
	print("</tr>\n");
	print("<tr><td colspan=\"2\" bgcolor=\"white\">\n");

	print("<table cellpadding=\"5\" cellspacing=\"2\" width=\"100%\">\n");

	if ($MODE == "UPD")
	{
		print("<tr>\n");
		print("<td colspan=\"3\" class=\"color02\"><b>ϡ󤫤ͭˤʤޤ</b></td>\n");
		print("</tr>\n");
	}

	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td width=\"20%\"><b>ɽ̾</b></td>\n");
	print("<td width=\"70%\"><b></b></td>\n");
	print("<td width=\"10%\"><b></b></td>\n");
	print("</tr>\n");

	for ($x=0; $x<count($url); $x++)
	{
		print("<tr bgcolor=\"f7f2e8\">\n");
		printf("<td nowrap>%s</TD>\n", htmlspecialchars($title[$x]));
		printf("<td>%s<br></td>\n", $comment[$x]);
		print("<td align=\"center\"><a href=\"" . PG_NAME() . "?MODE=UPD&no=$no[$x]\"><IMG SRC=\"" . DELETE . "\" BORDER=0></A></TD>\n");
		print("</tr>\n");
	}

	print("<tr>\n");
	print("<td colspan=\"3\" align=\"center\"><a href=\"digest_main.php?\">Ȥ</a></td>\n");
	print("</tr>\n");

	print("</table>\n");

	print("</td></tr>\n");
	print("</table>\n");
}


//==============================================================
// Function Name    : Upd_bkmk
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Upd_bkmk($no)
{
	global $JJ_USERNAME;
	$db = new DB_Test;
	$SQL = "delete from bkmk_digest where login_id = '$JJ_USERNAME' and bkmk_digest_id = '$no'";
	$db->query($SQL);
	$db->close();
}



//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start(PG_NAME());

// HTMLإå
include("common_printheader.inc");

if (!isset($MODE)){
	$MODE="";
}

if ($MODE == "UPD"){
	Upd_bkmk($no);
}

// ɽ
Print_bkmk($MODE);

// HTMLեå
include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/digest_shortcut_hosyu.php <==
<?php
//==============================================================
// Program Name		: 
// File Name		: digest_shortcut_hosyu.php
//--------------------------------------------------------------
// Date             : 2000/10/10
// Author           : M Iura
//--------------------------------------------------------------
// Note				: ֥åޡɽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 2002/01/15 Update
//                  : 
//==============================================================

require("jetjob.inc.php");
require("common_check.inc");	// 
require("common_login.php");	// 

define("DELETE",		$JJ_IMG_ROOT . "body/delete.gif");
define("IMG_SPACER",	$JJ_IMG_ROOT . "spacer.gif");		// 򥤥᡼


//==============================================================
// Function Name    : Get_bkmk
//--------------------------------------------------------------
// Note		        : ֥åޡ
//                  :
//==============================================================
Function Get_bkmk()
{
	global $JJ_USERNAME;

	$title=$url=$comment=$no=array();
	$db = new DB_Test;
	$db->query("SELECT * FROM bkmk_digest WHERE login_id = '$JJ_USERNAME' ORDER BY linkid, subcategoryid");
	$cnt = $db->nf();
	$x = 0;
	while ($db->next_record()) {
		$no[$x]     = $db->f("bkmk_digest_id");
		$linkid[$x] = $db->f("linkid");
		$subcat[$x] = $db->f("subcategoryid");
		$x++;
	}

	for ($x=0; $x<$cnt; $x++) {
		$db->query("SELECT * FROM bkmk_link WHERE subcategoryid = '$subcat[$x]' AND linkid = '$linkid[$x]'");
		$db->next_record();
		$title[$x] = $db->f("link_title");
		$url[$x] = $db->f("url");
		$comment[$x] = $db->f("biko");
	}

	$db->close();
	return array($title, $url, $comment, $no) ;
}


//==============================================================
// Function Name    : Print_bkmk
//--------------------------------------------------------------
// Note		        : Ǽľ
//                  :
//==============================================================
Function Print_bkmk($MODE)
{
	global $JJ_USERNAME;

	// ǡ
	list ($title, $url, $comment, $no) = Get_bkmk();

	print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"600\">\n");
	print("<tr align=\"center\">\n");
	print("<td width=\"50%\" class=\"color00\"><font color=\"white\"><b>硼ȥ󥯰</b></font></td>\n");
	print("<td width=\"50%\" bgcolor=\"#cccccc\">&nbsp;</td>\n");
	print("</tr>\n");
	print("<tr class=\"color00\">\n");
	printf("<td colspan=\"2\"><img src=\"%s\" width=\"1\" height=\"1\" alt=\"\"></td>\n", IMG_SPACER);
	print("</tr>\n");
	print("<tr><td colspan=\"2\" bgcolor=\"white\">\n");

	print("<table cellpadding=\"5\" cellspacing=\"2\" width=\"100%\">\n");

	if ($MODE == "UPD")
	{
		print("<tr>\n");
		print("<td colspan=\"3\" class=\"color02\"><b>ϡ󤫤ͭˤʤޤ</b></td>\n");
		print("</tr>\n");
	}

	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td width=\"20%\"><b>ɽ̾</b></td>\n");
	print("<td width=\"70%\"><b></b></td>\n");
	print("<td width=\"10%\"><b></b></td>\n");
	print("</tr>\n");

	for ($x=0; $x<count($url); $x++)
	{
		print("<tr bgcolor=\"f7f2e8\">\n");
		printf("<td nowrap>%s</TD>\n", htmlspecialchars($title[$x]));
		printf("<td>%s<br></td>\n", $comment[$x]);
		print("<td align=\"center\"><a href=\"" . PG_NAME() . "?MODE=UPD&no=$no[$x]\"><IMG SRC=\"" . DELETE . "\" BORDER=0></A></TD>\n");
		print("</tr>\n");
	}

	print("<tr>\n");
	print("<td colspan=\"3\" align=\"center\"><a href=\"digest_main.php?\">Ȥ</a></td>\n");
	print("</tr>\n");

	print("</table>\n");

	print("</td></tr>\n");
	print("</table>\n");
}


//==============================================================
// Function Name    : Upd_bkmk
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Upd_bkmk($no)
{
	global $JJ_USERNAME;
	$db = new DB_Test;
	$SQL = "delete from bkmk_digest where login_id = '$JJ_USERNAME' and bkmk_digest_id = '$no'";
	$db->query($SQL);
	$db->close();
}



//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start(PG_NAME());

// HTMLإå
include("common_printheader.inc");

if (!isset($MODE)){
	$MODE="";
}

if ($MODE == "UPD"){
	Upd_bkmk($no);
}

// ɽ
Print_bkmk($MODE);

// HTMLեå
include("common_printfooter.inc");

?>
